@@ -12,7 +12,7 @@ use warnings;
 
 package Pod::Weaver::PluginBundle::Author::RWSTAUNER;
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Pod::Weaver::PluginBundle::Author::RWSTAUNER::VERSION = '4.211';
+$Pod::Weaver::PluginBundle::Author::RWSTAUNER::VERSION = '4.212';
 # ABSTRACT: RWSTAUNER's Pod::Weaver config
 
 use Pod::Weaver::Config::Assembler;
@@ -31,7 +31,7 @@ sub _bundle_name {
 
 sub _for {
   my ($region) = @_;
-  [ $region, _exp('Region'),  { region_name => $region, allow_nonpod => 1 } ],
+  [ $region, _exp('Region'),  { region_name => $region, allow_nonpod => 1, flatten => 0 } ],
 }
 
 sub mvp_bundle_config {
@@ -139,7 +139,7 @@ Pod::Weaver::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Pod::Weaver config
 
 =head1 VERSION
 
-version 4.211
+version 4.212
 
 =head1 SYNOPSIS
 
@@ -172,6 +172,7 @@ This bundle is roughly equivalent to:
 
   [Region / test_synopsis]
   allow_nonpod = 1
+  flatten      = 0
   region_name  = test_synopsis
 
   [Generic / Synopsis]
